@@ -1,34 +1,31 @@
 """Class to handle project settings"""
 import configparser
-import platform
-from os import environ
-from pathlib import Path, PurePath
+from pathlib import Path
+from typing import Optional
 
 
 class MetronTaggerSettings:
     """Class to handle project settings"""
 
     @staticmethod
-    def get_settings_folder():
+    def get_settings_folder() -> Path:
         """Method to determine where the users settings should be saved"""
-        if platform.system() == "Windows":
-            folder = PurePath(environ["APPDATA"]).joinpath("MetronTagger")
-        else:
-            folder = Path.home() / ".MetronTagger"
-        return folder
+        # TODO: Removed the old windows directory code. Someone that has a windows
+        #       machine should probably write the code since I don't have one
+        return Path.home() / ".MetronTagger"
 
-    def __init__(self, config_dir=None):
+    def __init__(self, config_dir: Optional[str] = None) -> None:
         # Metron creditials
-        self.metron_user = ""
-        self.metron_pass = ""
-        self.sort_dir = ""
+        self.metron_user: str = ""
+        self.metron_pass: str = ""
+        self.sort_dir: str = ""
 
         self.config = configparser.ConfigParser()
 
-        if config_dir:
-            config_dir = Path(config_dir)
-
-        self.folder = config_dir or MetronTaggerSettings.get_settings_folder()
+        if not config_dir:
+            self.folder = MetronTaggerSettings.get_settings_folder()
+        else:
+            self.folder = Path(config_dir)
 
         self.settings_file = self.folder / "settings.ini"
 
@@ -41,7 +38,7 @@ class MetronTaggerSettings:
         else:
             self.load()
 
-    def load(self):
+    def load(self) -> None:
         """Method to retrieve a users settings"""
         self.config.read(self.settings_file)
 
@@ -54,7 +51,7 @@ class MetronTaggerSettings:
         if self.config.has_option("DEFAULT", "sort_dir"):
             self.sort_dir = self.config["DEFAULT"]["sort_dir"]
 
-    def save(self):
+    def save(self) -> None:
         """Method to save a users settings"""
         if not self.config.has_section("metron"):
             self.config.add_section("metron")
